+++
title = "Setting EXPORT_HUGO_SECTION to \"/\""
description = "Case where `EXPORT_HUGO_SECTION` is set to `/`."
tags = ["section", "root-level"]
draft = false
+++

`ox-hugo` Issue #[164](https://github.com/kaushalmodi/ox-hugo/issues/164)

This behaves the same as **not setting** `EXPORT_HUGO_SECTION` at all.

This post is created at the site root.
